@@ -493,7 +493,7 @@ module Cinch
         modes = ModeParser.parse_modes(msg.params[1], msg.params[2..-1])
         modes.each do |direction, mode, _|
           if direction == :add
-            @bot.modes << mode
+            @bot.modes << mode unless @bot.modes.include?(mode)
           else
             @bot.modes.delete(mode)
           end
@@ -629,6 +629,12 @@ module Cinch
                    })
     end
 
+    def on_313(msg, events)
+      # RPL_WHOISOPERATOR
+      user = User(msg.params[1])
+      update_whois(user, {:oper? => true})
+    end
+
     def on_317(msg, events)
       # RPL_WHOISIDLE
       user = User(msg.params[1])
@@ -642,21 +648,21 @@ module Cinch
       # RPL_ENDOFWHOIS
       user = User(msg.params[1])
 
-      if @whois_updates[user]
-        if @whois_updates[user].empty? && !user.attr(:unknown?, true, true)
-          user.end_of_whois(nil)
-        else
-          user.end_of_whois(@whois_updates[user])
-        end
-        @whois_updates.delete user
+      if @whois_updates[user].nil? ||
+         (@whois_updates[user].empty? && !user.attr(:unknown?, true, true))
+        user.end_of_whois(nil)
+        return
       end
+
+      user.end_of_whois(@whois_updates[user])
+      @whois_updates.delete user
     end
 
     def on_319(msg, events)
       # RPL_WHOISCHANNELS
       user     = User(msg.params[1])
       channels = msg.params[2].scan(/[#{@isupport["CHANTYPES"].join}][^ ]+/o).map {|c| Channel(c) }
-      @whois_updates[user].merge!({:channels => channels})
+      update_whois(user, {:channels => channels})
     end
 
     def on_324(msg, events)
@@ -679,8 +685,7 @@ module Cinch
       # RPL_WHOISACCOUNT
       user     = User(msg.params[1])
       authname = msg.params[2]
-
-      @whois_updates[user].merge!({:authname => authname})
+      update_user(user, {:authname => authname})
     end
 
     def on_331(msg, events)
@@ -845,7 +850,7 @@ module Cinch
 
     def on_671(msg, events)
       user = User(msg.params[1])
-      @whois_updates[user].merge!({:secure? => true})
+      update_whois(user, {:secure? => true})
     end
 
     # @since 2.0.0
